@@ -84,10 +84,10 @@ def ccdesign(n, center=(4, 4), alpha='orthogonal', face='circumscribed'):
     try:
         nc = len(center)
     except:
-        raise TypeError, 'Invalid value for "center": {:}. Expected a 1-by-2 array.'.format(center)
+        raise TypeError('Invalid value for "center": {:}. Expected a 1-by-2 array.'.format(center))
     else:
         if nc!=2:
-            raise ValueError, 'Invalid number of values for "center" (expected 2, but got {:})'.format(nc)
+            raise ValueError('Invalid number of values for "center" (expected 2, but got {:})'.format(nc))
 
     # Orthogonal Design
     if alpha.lower() in ('orthogonal', 'o'):
@@ -99,18 +99,18 @@ def ccdesign(n, center=(4, 4), alpha='orthogonal', face='circumscribed'):
     
     # Inscribed CCD
     if face.lower() in ('inscribed', 'cci'):
-        H1 = 2*ff2n(n) - 1
+        H1 = ff2n(n)
         H1 = H1/a  # Scale down the factorial points
         H2, a = star(n)
     
     # Faced CCD
     if face.lower() in ('faced', 'ccf'):
         H2, a = star(n)  # Value of alpha is always 1 in Faced CCD
-        H1 = 2*ff2n(n) - 1
+        H1 = ff2n(n)
     
     # Circumscribed CCD
     if face.lower() in ('circumscribed', 'ccc'):
-        H1 = 2*ff2n(n) - 1
+        H1 = ff2n(n)
     
     C1 = repeat_center(n, center[0])
     C2 = repeat_center(n, center[1])
@@ -119,4 +119,4 @@ def ccdesign(n, center=(4, 4), alpha='orthogonal', face='circumscribed'):
     H2 = union(H2, C2)
     H = union(H1, H2)
 
-    return H
\ No newline at end of file
+    return H
